#
# spec file for package kernel-firmware
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kernel-firmware
BuildRequires:  fdupes
BuildRequires:  kernel-default
BuildRequires:  suse-module-tools
Version:        20151109git
Release:        1.5
Summary:        Linux kernel firmware files
License:        SUSE-Firmware and GPL-2.0 and GPL-2.0+ and MIT
Group:          System/Kernel
Url:            https://git.kernel.org/cgit/linux/kernel/git/firmware/linux-firmware.git/
# Created with git archive | bzip2
Source0:        linux-firmware-%{version}.tar.xz
Source1:        firmware.sh
# ast_dp501_fw.bin generated from header file of xf86-video-ast: MIT/X11 License
Source2:        ast_dp501_fw.bin
%define __find_supplements bash %_sourcedir/firmware.sh --find-supplements

%define __ksyms_supplements bash %_sourcedir/firmware.sh --cache %{_builddir}/%{?buildsubdir}/find_supplements.cache --find-supplements
%define __ksyms_path ^/lib/firmware
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): coreutils
Requires(postun): coreutils
Provides:       qlogic-firmware
Obsoletes:      qlogic-firmware
Provides:       cxgb3-firmware
Obsoletes:      cxgb3-firmware
Provides:       ralink-firmware
Obsoletes:      ralink-firmware
Provides:       iwl1000-ucode
Obsoletes:      iwl1000-ucode
Provides:       iwl3945-ucode
Obsoletes:      iwl3945-ucode
Provides:       iwl4965-ucode
Obsoletes:      iwl4965-ucode
Provides:       iwl5000-ucode
Obsoletes:      iwl5000-ucode
Provides:       iwl5150-ucode
Obsoletes:      iwl5150-ucode
Provides:       iwl100-ucode
Obsoletes:      iwl100-ucode
Provides:       iwl1000-ucode
Obsoletes:      iwl1000-ucode
Provides:       iwl6000-ucode
Obsoletes:      iwl6000-ucode
Provides:       iwl6050-ucode
Obsoletes:      iwl6050-ucode
Provides:       iwl6000g2-ucode
Obsoletes:      iwl6000g2-ucode
Provides:       ath3k-firmware
Obsoletes:      ath3k-firmware

%description
This package contains the firmware for in-kernel drivers that was
previously included in the kernel. It is shared by all kernels >=
2.6.27-rc1.

%package -n ucode-amd
Supplements:    modalias(x86cpu:vendor%3A0002%3Afamily%3A*%3Amodel%3A*%3Afeature%3A*)
Summary:        Microcode updates for AMD CPUs
Group:          System/Kernel
Requires(post): coreutils
Requires(postun): coreutils

%description -n ucode-amd
This package contains the microcode files used by AMD CPUs.

%prep
%setup -q -n linux-firmware-%version
cp %{S:2} .

%build
# nothing to do

%install
mkdir -p %{buildroot}/lib/firmware
cp -avf * %{buildroot}/lib/firmware
rm -f %{buildroot}/lib/firmware/WHENCE
bash %_sourcedir/firmware.sh --kill-duplicates %buildroot/lib/firmware/
%fdupes %{buildroot}
rm -f find_supplements.cache
# In alsa-firmware
rm -f %{buildroot}/lib/firmware/ctefx.bin
rm -f %{buildroot}/lib/firmware/ctspeq.bin
# Devel files
rm -rf %{buildroot}/lib/firmware/carl9170fw

%clean
rm -rf %{buildroot}

%post
%{?regenerate_initrd_post}

%post -n ucode-amd
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%postun -n ucode-amd
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%posttrans -n ucode-amd
%{?regenerate_initrd_posttrans}

%files
%defattr(0644,root,root,0755)
%doc WHENCE README GPL-3 LICEN[CS]E.*
%exclude /lib/firmware/amd-ucode
%exclude /lib/firmware/LICENSE.amd-ucode
/lib/firmware/*

%files -n ucode-amd
%defattr(0644,root,root,0755)
/lib/firmware/amd-ucode
/lib/firmware/LICENSE.amd-ucode

%changelog
* Thu Dec 10 2015 tiwai@suse.de
- Fix dependencies for initrd macros (boo#958562)
- Fix missing dependency for ucode-amd, too (boo#958562)
- Call missing initrd macro at postun (boo#958562)
* Mon Nov  9 2015 tiwai@suse.de
- Updat to version 20151109git (commit bfeee58b5020)
  * radeon/amdgpu: update to latest firmware
  * remove executable bit from some firmware
  * add Skylake audio firmware
  * brcm: update firmware for the BCM4356 PCIe device
  * brcm: adding firmware for BCM4350 PCIe device
  * New minor DMC release for Skylake - ver1_23 (already existed
    in the package, old tarball dropped)
  * Removing old Skylake DMC
  * Add FW binary used by mwlwifi driver
  * ath10k: QCA99X0 hw2.0: add firmware 10.4.1.00030-1 and board.bin
  * ath10k: QCA6174 hw3.0: add WLAN.RM.2.0-00180-QCARMSWPZ-1
  * ath10k: QCA6174 hw2.1: add firmware WLAN.RM.1.1-00141 and board.bin
  * ath10k: QCA988X hw2.0: add firmware 10.2.4.70.9-2
  * ath10k: QCA988X hw2.0: add board.bin
  * Add firmware patch for Intel Bluetooth 7265 (D1)
  * brcmfmac: firmware refresh for BCM43602 PCIE devices
  * add support for the R-Car H3 xHCI controllers
  * Refresh / fix WHENCE and license descriptions
* Tue Oct 27 2015 tiwai@suse.de
- Update Skylake DMC firmware to 1.23 (boo#952134)
* Fri Sep 25 2015 tiwai@suse.de
- Update toversion 20150925git (commit f88e5c2e2)
  * Intel Bluetooth 7260/7265 f/w updates
  * qmss accumulator pdsp firmware for keystone SoCs
  * New minor DMC release for Skylake - ver1_22
  * New minor DMC release for Broxton - ver1_06
* Mon Sep  7 2015 tiwai@suse.de
- Update to version 20150907git (commit 6ebf5d57) (boo#944661):
  * amdgpu: add firmware for VI asics
  * ar3k: add to support AR3012 v2.1 firmware
  * Add Intel OPA hfi1 firmware
  * New major GuC/DMC releases for Skylake
  * New minor DMC release for Broxton - ver1_05
  * update firmware to revision 1.14.4.0
  * tegra: Update XHCI firmware to v50.10 for T210
  * wilc1000: add firmware for wilc1000 802.11n driver
  * usbdux: usbduxsigma firmware updates
  * Update to QAT dh895xxcc UOF firmware and a new QAT MMP FW
  * rtl_bt: correct RTL8723A firmware file
  * bnx2x: Update to FW version 7.12.30
  * tegra: add GK20A FECS/GPCCS firmware
* Wed Jul 15 2015 tiwai@suse.de
- Update to version 20150715git (commit 69640304) (boo#937628):
  * Intel BT 8260 firmware
  * Add firmware for Cavium LiquidIO 210NV, 210SV, and 410NV cards
  * Audio firmware for Braswell
  * qca: add BT firmware files to support QCA ROME chips
  * cxgb4: Add BT adapter PHY firmware
  * add firmware for atusb driver
  * radeon: add firmware for VCE1.0 hardware
  * iwlwifi: add new -13 firmware for iwlmvm devices
  * i915 Skylake DMC/GuC firmwares
* Tue Jun 16 2015 tiwai@suse.de
- Update to version 20150616git (commit 3161bfa479d5) (boo#934932):
  Update firmware patch for Intel Bluetooth 7260 (B3/B4)
  Update firmware patch for Intel Bluetooth 7260 (B5/B6)
  Update firmware patch for Intel Bluetooth 7265 (C0/D0)
  Update firmware patch for Intel Bluetooth 7265 (C0/D0)
  wl18xx: update firmware file, remove conf file
  Add Realtek Bluetooth HCD firmware
  brcm: add brcmfmac43241b5-sdio.bin to WHENCE
  Fix nvidia/tegra210/xusb.bin permissions
  brcm: add firmware for BCM4324(1) B5 chipset
  brcm: replace non-working firmware for BCM4339
  brcm: add firmware for BCM43570 PCIe device
  brcm: add firmware for BCM43569 USB device
  iwlwifi: update -12.ucode for 3160 / 7260 / 7265 / 7265D
  ath3k: update AR3012 2.2.1 firmware with v.170
  WHENCE: note nvidia xusb.bin firmware versions
  tegra: Add XHCI firmware v50.07 for T210
  cxgb4: update firmware to revision 1.13.32.0 for T4 and T5
  brcm: add firmware for BCM43340/1 SDIO devices
  brcm: add firmware for BCM4339 SDIO device
  brcm: add firmware for BCM43455 SDIO device
  brcm: add firmware files for BCM43602 PCIe device
  brcm: add firmware for BCM4356 PCIe device
  brcm: add firmware for BCM43242 USB device
  radeon: Update Kaveri MEC firmware to #396
  ath10k: add firmware 10.2.4.45 as firmware-4.bin
  Add v1.4.0 firmware for ath9k_htc.
  ath9k_htc: revert versions in WHENCE to 1.3.1
  iwlwifi: update -10.ucode for 3160 / 7260 / 7265 / 7265D
  firmware: tegra: Add XHCI firmware v45.46 for T124
  ath9k_htc: update versions in WHENCE
  rtl_nic: update firmware for RTL8168H and RTL8107E
  Fix qat_895xcc.bin permissions
  Add QLogic BR Series Adapter Firmware
  Fix firmware files with executable permission set
  iwlwifi: update -10.ucode for 3160 / 7260 / 7265 / 7265D
* Mon Mar 23 2015 mmarek@suse.cz
- Fix the filelist of amd-ucode.
* Mon Feb  9 2015 duwe@suse.com
- David Woodhouse is not maintaining this all by himself any more,
  switch to proper upstream repository and get a fresh snapshot.
  (bumping version to 20150209git)
* Sat Dec 13 2014 dimstar@opensuse.org
- Require coreutils for %%pre scripts. In some instances (mainly
  kiwi builds) this package can end up being installed before
  coreutils, having some errors spit in the %%pre phase.
* Sat Nov 22 2014 tiwai@suse.de
- Updated to git snapshot 20141122:
  Realtek WiFi and Ethernet updates and Intel BT updates
  (bnc#906212)
* Mon Sep  8 2014 eich@suse.com
- Add ast_dp501_fw.bin (bnc#871134 & bnc#895608)
  file generated from an array in a header file of xf86-video-ast:
  MIT/X11 License
* Wed Sep  3 2014 tiwai@suse.de
- Sync with SLE12 package
  * Includes previously cherry-picked QLogic firmware (bnc#879633)
  * Intel BT firmware updates
  * cxgb4 firmware update to revision 1.11.27.0
  * bnx2x firmware version 7.10.51 (bnc#887382)
  * dvb-fe-xc5000c-4.1.30.7.fw for xc5000 (bnc#884321)
  * Drop the obsoleted mkinitrd scripts
  * Use standard macros, posttrans for initrd updates
- Update to git snapshot 20140903:
  * Another Intel BT firmware updates (bnc#894810)
* Tue Jun 24 2014 tiwai@suse.de
- Updated to git snapshot 20140624:
  including previous intel firmware files
* Fri Apr  4 2014 tiwai@suse.de
- Add Intel 7265 BT firmware (FATE#316958):
  ibt-hw-37.8.10-fw-1.10.2.27.d.bseq
  ibt-hw-37.8.bseq
* Mon Mar 24 2014 tiwai@suse.de
- Add Intel 7265 WiFi firmware (FATE#316958)
* Wed Mar 19 2014 tiwai@suse.de
- Update to git snapshot 20140319 (bnc#869039)
  * brcm: add firmware for the BCM43362 WLAN device
  * iwlwifi: update firmware for 7260 / 3160 devices
  * WHENCE: Fix oddly capitalised instances of 'File'
  * wl18xx: add version 3 of the wl18xx firmware
  * rtlwifi: Add firmware for rtl8192ee
  * myri10ge: update firmware to 1.4.57
  * bnx2x: Update to FW 7.8.19
  * Remove executable permissions from firmware files
  * rtlwifi: Add firmware for rtl8821ae
  * radeon: add ucode for HAWAII GPUs
  * rtlwifi: Add firmware for r8723au
  * iwlwifi: update firmware for 7260 / 3160 devices
  * iwlwifi: update firmware for 7260 / 3160 devices
  * linux-firmware: 3.2.3.0 Firmware for Brocade Adapters
  * cxgb4: Updated T4 firmware, add T5 firmware
  * qla2xxx: Update ql2{4,5}00_fw.bin to version 7.01.00
  * linux-firmware: Update Intel Bluetooth devices firmware patch files
  * firmware: cw1200: Add firmware for the ST-E CW1200 WLAN chipset.
  * emi62: Provide the correct bitstream
  * linux-firmware: add Marvell SD8897-B0 firmware combo image
  * linux-firmware: update Marvell PCIe/USB 8897-B0 firmware combo image
  * rtlwifi: Add new firmware files for rtl8188eu
  * rtlwifi: Add new firmware files for rtl8192cu
  * brcm: add firmware file for the BCM4335 SDIO chipset
  * brcm: add firmware for newer version of BCM43241 SDIO chipset
  * brcm: add firmware file for BCM43241 SDIO chipset
  * brcm: rename firmware names expressing host interface type
  * ti-connectivity: add wl1251 firmware and license
  * linux-firmware: Add Brocade FC/FCOE Adapter firmware files
  * radeon: add ucode for KAVERI GPUs
  * radeon: add smc ucode for BONAIRE
  * linux-firmware: Add firmware patch file for Intel Bluetooth device(3160)
  * linux-firmware: add version information for Intel Bluetooth firmware
  * cw1200: Add SDD file for the Sagrad SG901-1091/1098 WLAN modules.
  * Fix filename for Intel Bluetooth firmware
  * linux-firmware: update Intel Bluetooth firmware patch file
  * moxa: Fix firmware file names.
  * moxa: Add firmware for some of the Moxa USB-Serial hubs
  * radeon: add ucode for KABINI GPUs
  * radeon: add ucode for BONAIRE GPUs
  * radeon: add smc ucode for radeon GPUs
- Remove obsoleted iwlwifi-4965 and carl9170w sources
* Thu Dec 19 2013 meissner@suse.com
- fixed last submission to actually build.
* Tue Dec 10 2013 trenn@suse.de
- Add mkinitrd script to add AMD microcode to initrd.
  This is needed because microcode driver is built in or gets loaded
  automatically via udev early. Therefore the microcode has to be available
  in initrd already.
  This must not be mixed up with early micorcode loading. This feature will
  not be implemented via mkinitrd. Dracut is doing early microcode loading.
- bnc#847158
- mkinitrd scripts:
  - mkinitrd_setup-amd_microcode.sh
    Adding microcode to the initrd
  - mkinitrd_boot-amd_microcode.sh
    Triggering the reload at boot
* Mon Dec  9 2013 trenn@suse.de
- Correct Supplements string so that the package gets correctly installed
  on machines with AMD CPUs
  bnc#847158
* Mon Oct 21 2013 jeffm@suse.com
- Use qlogic firmware from linux-firmware instead of the separate
  archive (bnc#846629).
* Mon Jul 29 2013 jeffm@suse.com
- Updated to git snapshot 2013/07/14
  - Radeon ucode update:
  - radeon: add ucode for KABINI GPUs
  - radeon: add ucode for BONAIRE GPUs
  - radeon: add smc ucode for radeon GPUs
* Thu Jul 25 2013 jeffm@suse.com
- Moved amd-ucode from microcode_ctl into new ucode-amd package.
* Fri Jul 19 2013 jeffm@suse.com
- Remove carl9170fw source files from package
* Mon Jul 15 2013 jeffm@suse.com
- Updated to git snapshot 2013/7/10
  - Add AMD microcode patch firmware files
  - Add Intel Bluetooth firmware patch files
  - Add firmware files for Creative CA0132 HD-audio codec
  - Add firmware files for mtk mt7630/mt7650 chipsets
  - Add firmware for mwl8k 8764 chip
  - Add go7007 firmware.
  - Add symlinks for old go7007 firmware filenames
  - Fix formatting of LICENCE.ca0132
  - Increment ap firmware API for mwl8k 8366 chip
  - Move sd8688*.bin images into mrvl/ tree
  - Revert "carl9170: Add checksum during installation, as preferred by the driver"
  - add Marvell PCIe8897-B0 WLAN firmware image
  - add Marvell SD8797-B0 firmware image
  - ar3k: add Bluetooth support for QCA98XX/QCA24XX
  - bnx2x: update fw to 7.8.17
  - cx231xx/cx23885: Remove incorrect Conexant CX23885 firmware
  - iwlwifi: add firmware for 7260 / 3160 devices
  - netxen_nic: Add FTP location of phanfw.bin in WHENCE file
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.590
  - radeon: add ucode for OLAND GPUs
  - radeon: add ucode for SUN/HAINAN GPUs
  - radeon: add updated ucode for UVD
  - rp2: Initial commit of Comtrol RocketPort 2 microcode
  - rtl_nic: Add firmware rtl8168g-3
  - rtl_nic: add firmware rtl8106e-2
  - rtl_nic: add firmware rtl8411-2
  - rtl_nic: update firmware for RTL8168G
  - rtlwifi/rtl8188ee: Add firmware for new driver
  - tg3: Add EEE support firmware for 57766 cards
  - update Marvell SD8797-B0 firmware image
  - wl127x/wl128x: update firmwares
  - wl18xx: add default configuration binary
  - wl18xx: add version 2 of the wl18xx firmware
* Thu Feb 21 2013 Larry.Finger@lwfinger.net
- fix previous fix to build on factory/12.3
* Thu Feb 14 2013 Larry.Finger@lwfinger.net
- Updated to git snapshot 2013/1/14
  - carl9170: add firmware
  - qla2xxx: Update ql2400_fw.bin and ql2500_fw.bin to version 5.08.00
  - brcm: Add ucode support for bcm4313 iPA variant
  - linux-firmware: Add Marvell USB8797-B0 firmware image, Version 14.69.11.p179
  - s5p-mfc: Add s5p-mfc.fw for Exynos4 series
  - s5p-mfc: Add s5p-mfc-v6.fw for Exynos5 series
  - ar5523: Add firmware for new driver
  - Update patch and syscfg files for QCA9564
  - rtl_nic: Update firmware for RTL8168G to Version: 0.0.3
  - cxgb4: Update firmware to revision 1.6.2.0
  - bnx2x: Update fw to 7.8.2
  - r8712u: Revert to firmware from vendor driver v7_0.20100831
  - Update rampatch file for AR9462
  - netxen_nic: Update QLogic phanfw.bin to version 4.0.588
  - rtl8723e: Add firmware for new driver
  - ath6k: add firmware for AR6004 hw1.3
  - Marvell SD8787: update to v14.66.9.p96
  - Marvell SD8686: update to v9.70.20.p0
  - iwlwifi: update firmware for 6205 to version 18.168.6.1
* Fri Aug 24 2012 mmarek@suse.cz
- Package also license files (bnc#776576)
* Thu Jul 26 2012 jeffm@suse.com
- Updated to git snapshot 2012/7/19
  - brcm: add bcm4334 firmware for brcmfmac
  - r8712u: Update to latest firmware
  - rtl_nic: update firmware for RTL8168G
  - Add syscfg and patch files for AR3002 2.2.1
  - rtl_nic: add new firmware for RTL8168G, RTL8106E, RTL8411, RTL8168F
  - ar3k: add patch and sysconfig for Qualcomm Atheros AR9462
  - rtlwifi: rtl8192ce: rtl8192se: rtl8192de: Update to
    rtl_92ce_92se_92de_linux_mac80211_0004.0816.2011 driver
  - wl18xx: add firmware for WiLink8 WLAN chips
  - wl127x/wl128x: add new firmware series as version 5
  - rt2800pci:Firmware update v1
  - cxgb4: update firmware to revision 1.4.23.0
* Mon Jul  9 2012 jslaby@suse.de
- add carl9170-1.fw (bnc#763568)
* Tue Jun  5 2012 jeffm@suse.com
- Updated to git snapshot 2012/5/21
  - Many updates and additions
  - Replaced by git version:
  - iwlwifi-105-6.ucode
  - iwlwifi-135-6.ucode
  - iwlwifi-2000-6.ucode
  - iwlwifi-2030-6.ucode
  - bnx2/bnx2-mips-06-6.2.3.fw
  - bnx2/bnx2-mips-09-6.2.1b.fw
  - t4fw.bin (also updated to 1.4.16.0)
  - Removed:
  - brcm/bcm4329-fullmac-4.txt (was a development board)
  - mwl8335_duplex.fw (driver never included)
  - Renamed:
  - libertas/lbtf_usb.bin -> lbtf_usb.bin (as requested by driver)
* Tue May  8 2012 jslaby@suse.cz
- Add 4 iwlwifi firmware files. (bnc#760857)
  iwlwifi-105-6.ucode
  iwlwifi-135-6.ucode
  iwlwifi-2000-6.ucode
  iwlwifi-2030-6.ucode
* Fri Mar  2 2012 jlee@novell.com
- Add 2 new bnx2 firmware files. (bnc#746686)
  bnx2/bnx2-mips-06-6.2.3.fw
  bnx2/bnx2-mips-09-6.2.1b.fw
* Wed Dec 14 2011 coolo@suse.com
- as spdx.org has no concept of firmware, we decided to mark it as
  SUSE-Firmware
* Tue Oct 25 2011 coolo@suse.com
- update from git, ftp.kernel.org is stil down. Some smaller updates
* Thu Aug 25 2011 mls@suse.de
- fix supplements generation with rpm-4.9
* Fri Aug 12 2011 dmueller@suse.de
- add provides/obsoletes for ath3k-firmware
- Update to 20110731:
  * iwlwifi-6000g2a-5.ucode: Updated to v17.168.5.3
  * ath6kl - Atheros support for AR6003 WiFi-Bluetooth combo module
  * drxk - Micronas DRX-K demodulator driver
  * ene-ub6250 -- ENE UB6250 SD card reader driver
- update qlogic firmware to 5.06.00 (bnc#702696)
- add iwlwifi-4965-1.ucode (was additionally in iwl4965-ucode
  package before)
- Add latest firmware (1.3.10.0) for cxgb4 from Chelsio git (bnc#711432)
* Tue Aug  9 2011 mmarek@suse.cz
- Remove the PE520.cis symlink, it was only needed for SLE11-SP2.
* Thu Aug  4 2011 dmueller@suse.de
- add provides/obsoletes for
  iwl100-ucode, iwl1000-ucode, iwl6000-ucode, iwl6050-ucode,
  iwl6000g2-ucode
* Mon Jul 25 2011 mmarek@novell.com
- Add symlink for cis/PE520.cis (bnc#707960#c8)
* Thu Jul 14 2011 dmueller@suse.de
- update to 20110709:
  * provides more stable iwlwifi drivers
  * remove the need for symlinking bcm43xx-0.fw
* Tue Jul 12 2011 mmarek@novell.com
- Revert the workaround for bnc#673054, the files exist in the
  tarball now.
* Tue Jul 12 2011 mmarek@novell.com
- Fix firmware.sh for 3.0
* Thu Feb 24 2011 gregkh@suse.de
- create symlinks for Broadcom driver (bnc#673054)
* Sat Feb  5 2011 johannesobermayr@gmx.de
- Add scm service for automatical updates
* Wed Dec 15 2010 gregkh@suse.de
- update to 20101214 version for 2.6.37+ kernel
* Wed Nov 24 2010 coolo@novell.com
- update to 20101113 tarball for 2.6.36+ kernel
* Thu Jul  1 2010 gregkh@suse.de
- update to the 20100617 tarball, which has lots of updates that
  the 2.6.34 kernel needs (bnc#619225).
* Fri May 14 2010 mmarek@suse.cz
- Do not install files already installed by the kernel (bnc#598624).
* Fri May 14 2010 mmarek@suse.cz
- firmware-supplements.sh: Fallback to the last installed kernel.
* Wed May 12 2010 mmarek@suse.cz
- Run firmware-supplements.sh at build time. It's not a perfect
  solution, because kernel-default has a different set of modules
  among architectures, but better than a manually updated file.
* Fri Apr 23 2010 mmarek@suse.cz
- Update firmware-supplements.txt using module aliases from
  kernel-desktop-2.6.34-5.2.i586 (bnc#598624).
* Fri Apr 23 2010 mmarek@suse.cz
- Silence the firmware-supplements.sh script.
* Thu Mar  4 2010 coolo@novell.com
- hacking find_supplements macro
* Thu Mar  4 2010 coolo@novell.com
- update supplements.txt
* Thu Mar  4 2010 coolo@novell.com
- update to 20100227 snapshot (no changelog provided)
* Tue Dec 15 2009 gregkh@suse.de
- update to 20091215 snapshot
- added RealTek 8192E firmware
* Mon Oct 12 2009 mmarek@suse.cz
- provide/obsolete iwl1000-ucode.
* Mon Oct  5 2009 mmarek@suse.cz
- Add a script to semi-automatically generate modalias supplements.
* Mon Oct  5 2009 mmarek@suse.cz
- provide obsoleted packages.
* Thu Oct  1 2009 mmarek@suse.cz
- update to 20090821
  * includes newer iwlwifi firmware (bnc#537112)
- use fdupes
* Mon Aug  3 2009 gregkh@suse.de
- add obsoletes for ralink-firmware (bnc#503836)
* Thu Apr 23 2009 gregkh@suse.de
- initial package
